@@ -7,16 +7,16 @@
 */
 
 /* .Fortran calls */
-extern void F77_NAME(lrmfit)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(lrmll)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(matinv)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(ormuv)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void F77_NAME(robcovf)(void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(robcovf)(void *, void *, void *, void *, void *, void *, void *, void *);
 
 static const R_FortranMethodDef FortranEntries[] = {
-    {"lrmfit",  (DL_FUNC) &F77_NAME(lrmfit),  22},
+    {"lrmll",   (DL_FUNC) &F77_NAME(lrmll),   16},
     {"matinv",  (DL_FUNC) &F77_NAME(matinv),  11},
     {"ormuv",   (DL_FUNC) &F77_NAME(ormuv),   18},
-    {"robcovf", (DL_FUNC) &F77_NAME(robcovf),  9},
+    {"robcovf", (DL_FUNC) &F77_NAME(robcovf),  8},
     {NULL, NULL, 0}
 };
 
